==> kubernetes-client-4.12.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/discovery/v1beta1/EndpointSliceOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.discovery.v1beta1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.discovery.DoneableEndpointSlice;
import io.fabric8.kubernetes.api.model.discovery.EndpointSlice;
import io.fabric8.kubernetes.api.model.discovery.EndpointSliceList;
import io.fabric8.kubernetes.api.model.discovery.DoneableEndpointSlice;

import java.util.Map;
import java.util.TreeMap;


public class EndpointSliceOperationsImpl extends HasMetadataOperation<EndpointSlice, EndpointSliceList, DoneableEndpointSlice, Resource<EndpointSlice, DoneableEndpointSlice>> {

  public EndpointSliceOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public EndpointSliceOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public EndpointSliceOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("discovery")
    .withApiGroupVersion("v1beta1")
    .withPlural("endpointslices"));
    this.type = EndpointSlice.class;
    this.listType = EndpointSliceList.class;
    this.doneableType = DoneableEndpointSlice.class;
  }

  public EndpointSliceOperationsImpl newInstance(OperationContext context) {
    return new EndpointSliceOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.0.2-sources.jar: io/fabric8/kubernetes/client/dsl/internal/discovery/v1beta1/EndpointSliceOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.discovery.EndpointSlice;
import io.fabric8.kubernetes.api.model.discovery.EndpointSliceBuilder;
import io.fabric8.kubernetes.api.model.discovery.EndpointSliceList;

import java.util.Map;
import java.util.TreeMap;


public class EndpointSliceOperationsImpl extends HasMetadataOperation<EndpointSlice, EndpointSliceList, Resource<EndpointSlice>> {

  public EndpointSliceOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public EndpointSliceOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public EndpointSliceOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("discovery.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("endpointslices"));
    this.type = EndpointSlice.class;
    this.listType = EndpointSliceList.class;
  }

  public EndpointSliceOperationsImpl newInstance(OperationContext context) {
    return new EndpointSliceOperationsImpl(context);
  }

  @Override
  public EndpointSlice edit(Visitor... visitors) {
    return patch(new EndpointSliceBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
